import 'package:duration_picker/duration_picker.dart';
import 'package:flutter/material.dart';

class DurationSelector extends StatefulWidget {
  final String title;
  final Duration duration;
  final Function onChanged;

  DurationSelector(
      {required this.duration, required this.onChanged, required this.title});

  @override
  _DurationSelectorState createState() => _DurationSelectorState();
}

class _DurationSelectorState extends State<DurationSelector> {
  String getFormatedDuration() {
    String twoDigits(int n) => n.toString().padLeft(2, "0");
    String twoDigitMinutes = twoDigits(widget.duration.inMinutes.remainder(60));
    return "${twoDigits(widget.duration.inHours)}h$twoDigitMinutes";
  }

  void handlePressed() {
    showDurationPicker(
      context: context,
      initialTime: widget.duration,
    ).then((value) {
      if (value == null) return;
      widget.onChanged(value);
    });
  }

  @override
  Widget build(BuildContext context) {
    MediaQueryData queryData = MediaQuery.of(context);
    double sh = queryData.size.height;

    return Column(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(widget.title,
            style: TextStyle(color: Color(0XFFBEBEBE), fontSize: 18)),
        SizedBox(height: sh * 0.01),
        TextButton(
            onPressed: handlePressed,
            child: Container(
                width: 90,
                child: Row(children: [
                  Text(getFormatedDuration(),
                      style: TextStyle(color: Color(0XFFBEBEBE), fontSize: 14)),
                  Spacer(),
                  Icon(Icons.access_time, color: Color(0XFFBEBEBE), size: 14)
                ])),
            style: ButtonStyle(
                backgroundColor: MaterialStateProperty.resolveWith<Color>(
                    (Set<MaterialState> states) {
                  return Colors.transparent;
                }),
                shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                    RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(10.0),
                        side: BorderSide.none)))),
      ],
    );
  }
}
