import 'package:flutter/material.dart';

class EmployeeButton extends StatefulWidget {
  final String title;
  final Color color;
  final Function onPress;
  final bool selected;

  EmployeeButton(
      {required this.title,
      this.color = const Color(0XFFF57C00),
      required this.onPress,
      this.selected = false});

  @override
  _EmployeeButtonState createState() => _EmployeeButtonState();
}

class _EmployeeButtonState extends State<EmployeeButton> {
  String getNameInitials() {
    if (widget.title == '') return '';
    RegExp regExp = new RegExp("^([^\\s]*?)\\s([^\\s]*)\$");

    if (!regExp.hasMatch(widget.title)) return widget.title[0];
    // Iterable<RegExpMatch> matches = regExp.allMatches(widget.title);
    RegExpMatch match = regExp.firstMatch(widget.title)!;

    return match.group(1)![0] + match.group(2)![0];
  }

  @override
  Widget build(BuildContext context) {
    MediaQueryData queryData = MediaQuery.of(context);
    final double sw = queryData.size.width;
    // final double sh = queryData.size.height;

    return Container(
      width: sw * 0.16,
      child: ElevatedButton(
          onPressed: () => widget.onPress(),
          style: ButtonStyle(
              backgroundColor: MaterialStateProperty.resolveWith<Color>(
                (Set<MaterialState> states) {
                  return Color(0XFF272c39);
                },
              ),
              shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                  RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(20.0),
                      side: widget.selected == true
                          ? BorderSide(width: 2, color: widget.color)
                          : BorderSide.none))),
          child: Padding(
            padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
            child: Container(
              child: Row(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  CircleAvatar(
                    backgroundColor: widget.color,
                    child: Text(getNameInitials(),
                        style: TextStyle(
                            color: Colors.white, fontSize: sw * 0.015)),
                    radius: sw * 0.02,
                  ),
                  Expanded(
                    child: Padding(
                      padding:
                          EdgeInsets.only(left: sw * 0.01, right: sw * 0.01),
                      child: Text(widget.title,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                              color: Colors.white,
                              fontSize: sw * 0.01,
                              fontWeight: FontWeight.bold)),
                    ),
                  )
                ],
              ),
            ),
          )),
    );
  }
}
