import 'package:flutter/material.dart';

enum Large_Button_Color { primary, accent }

class LargeButton extends StatefulWidget {
  final String title;
  final Function onPress;
  final bool disabled;
  final Large_Button_Color color;

  LargeButton(
      {required this.title,
      required this.onPress,
      this.disabled = false,
      this.color = Large_Button_Color.primary});

  @override
  _LargeButtonState createState() => _LargeButtonState();
}

class _LargeButtonState extends State<LargeButton> {
  Color getColor() {
    switch (widget.color) {
      case Large_Button_Color.primary:
        return Theme.of(context).primaryColor;
      case Large_Button_Color.accent:
        return Color(0xFF9F4A69);
      default:
        return Color(0XFFFFFF);
    }
  }

  @override
  Widget build(BuildContext context) {
    MediaQueryData queryData = MediaQuery.of(context);
    final double buttonFontSize = queryData.size.width * 0.015;
    final double buttonTextPadding = queryData.size.height / 100 * 1.5;

    return SizedBox(
      width: double.infinity,
      child: ElevatedButton(
        onPressed: widget.disabled == true ? null : () => widget.onPress(),
        style: ButtonStyle(
            backgroundColor: MaterialStateProperty.resolveWith<Color>(
              (Set<MaterialState> states) {
                return getColor()
                    .withOpacity(widget.disabled == true ? 0.4 : 1);
              },
            ),
            shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(10.0),
                    side: BorderSide.none))),
        child: Padding(
          padding: EdgeInsets.only(
              top: buttonTextPadding, bottom: buttonTextPadding),
          child: Text(widget.title,
              style: TextStyle(fontSize: buttonFontSize, color: Colors.black)),
        ),
      ),
    );
  }
}
