import 'package:flutter/material.dart';
import 'package:timetracker_common/src/admin/widgets/deleteDialog.dart';
import 'package:timetracker_common/src/admin/widgets/largeButton.dart';
import 'package:timetracker_common/src/admin/widgets/nameTextfield.dart';
import 'package:timetracker_common/src/admin/widgets/tabButton.dart';

class TabHeader extends StatefulWidget {
  final List<String> tabs;
  final String currentTab;
  final Function onTabChanged;
  final TextEditingController headerTitleController;
  final String defaultTitle;
  final Function onSave;
  final Function onDelete;

  TabHeader(
      {required this.tabs,
      required this.currentTab,
      required this.onTabChanged,
      required this.headerTitleController,
      required this.defaultTitle,
      required this.onSave,
      required this.onDelete});

  @override
  _TabHeaderState createState() => _TabHeaderState();
}

class _TabHeaderState extends State<TabHeader> {
  void handleDeleteDialog() {
    showDialog(
        context: context,
        builder: (_) => DeleteDialog(
            targetName: widget.defaultTitle, onConfirm: widget.onDelete),
        barrierDismissible: false);
  }

  @override
  Widget build(BuildContext context) {
    MediaQueryData queryData = MediaQuery.of(context);
    double sh = queryData.size.height;
    double sw = queryData.size.width;

    return Container(
      width: double.infinity,
      decoration: BoxDecoration(
          border:
              Border(bottom: BorderSide(width: 0.3, color: Color(0XFFB4B4B4)))),
      child: Padding(
        padding: EdgeInsets.only(left: sw * 0.05, top: sh * 0.05),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.end,
          children: [
            Column(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Container(
                      width: 200,
                      child: NameTextfield(
                          controller: widget.headerTitleController,
                          placeholder: widget.defaultTitle)),
                  Padding(
                      padding: EdgeInsets.only(top: sh * 0.03),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.start,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: widget.tabs
                            .map((e) => Padding(
                                  padding: EdgeInsets.only(right: sw * 0.01),
                                  child: TabButton(
                                      title: e,
                                      selected: e == widget.currentTab,
                                      onPressed: () => widget.onTabChanged(e)),
                                ))
                            .toList(),
                      ))
                ]),
            Expanded(
              child: Padding(
                padding: const EdgeInsets.only(bottom: 12.0, right: 12.0),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.end,
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Container(
                        width: sw * 0.08,
                        child:
                            LargeButton(title: 'Save', onPress: widget.onSave)),
                    SizedBox(width: sw * 0.01),
                    Container(
                      width: sw * 0.08,
                      child: LargeButton(
                          title: 'Delete',
                          onPress: handleDeleteDialog,
                          color: Large_Button_Color.accent),
                    )
                  ],
                ),
              ),
            )
          ],
        ),
      ),
    );
  }
}
